@@ -12,7 +12,11 @@ pub trait Pane {
     fn handle_input(app: &mut TaskwarriorTui, input: KeyCode) -> Result<()>;
     fn change_focus_to_left_pane(app: &mut TaskwarriorTui) {
         match app.mode {
-            Mode::Tasks(_) => {}
+            Mode::Tasks(_) => {
+                if app.config.uda_change_focus_rotate {
+                    app.mode = Mode::Calendar;
+                }
+            }
             Mode::Projects => app.mode = Mode::Tasks(Action::Report),
             Mode::Calendar => {
                 app.mode = Mode::Projects;
@@ -23,7 +27,11 @@ pub trait Pane {
         match app.mode {
             Mode::Tasks(_) => app.mode = Mode::Projects,
             Mode::Projects => app.mode = Mode::Calendar,
-            Mode::Calendar => {}
+            Mode::Calendar => {
+                if app.config.uda_change_focus_rotate {
+                    app.mode = Mode::Tasks(Action::Report);
+                }
+            }
         }
     }
 }
